#ifndef OPTIONS_H
#define OPTIONS_H

#include "cfg.h"

class options : public QWidget
{
    Q_OBJECT

public:
    explicit options(QWidget *parent = 0);
    ~options();

public slots:
    void load_cfg();
    void save_cfg();
    void createCfg();
    void frameskipChanged(QString value);

private:
    /*
      gpsp [-breack a][-accel][-screen b][-nosound][-fskip c][-fskip_value d][-fstype e][-sound_buffer f]
    */

    QCheckBox *chkAccel;
    QComboBox *cmbScreen;
    QCheckBox *chkNoSound;
    QComboBox *cmbFrameskip;
    QSpinBox *numFrameskipValue;
    QComboBox *cmbFsType;
    QComboBox *cmbSoundBuffer;

protected:
    void hideEvent(QHideEvent *);


};

#endif // OPTIONS_H
